Sacred Deer bot for Slack
-------------------------

How to use

#. Clone the repo and enter the project folder.

#. Install package by running the command:

   .. code-block:: console

      pip install .

   (on PyPi soon).

#. Create bot user with name ``sacred_deer`` in your Slack team
   and copy his token provided by Slack.

#. Export bot token as the environment variable:

   .. code-block:: console

      export TOKEN=123k-jkj213123kjkjk...

#. To run the bot, execute command:

   .. code-block:: console

      deer

#. Ask your stupid questions in Slack channel with ``@sacred_deer``.

Default language of the Deer is Russian, you can ask him for answer
in one of the other languages by adding ``en``, ``ua`` or ``de`` after the
``@sacred_deer``.
